==> deepin-home_0.0.5.orig.tar.xz: deepin-home-0.0.5/translations/deepin-home/de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>Card1</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Card1.qml" line="88"/>
        <source>Coming</source>
        <translation>Kommend</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="50"/>
        <source>Communication</source>
        <translation>Kommunikation</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="51"/>
        <source>Discuss and share here</source>
        <translation>Diskutieren und teilen Sie hier</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="60"/>
        <source>Bug Report</source>
        <translation>Problembericht</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="61"/>
        <source>Report issues you found</source>
        <translation>Melden Sie gefundene Probleme</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="68"/>
        <source>Suggestions</source>
        <translation>Vorschläge</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="69"/>
        <source>Submit your suggestions</source>
        <translation>Reichen Sie Ihre Vorschläge ein</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="83"/>
        <source>Resources</source>
        <translation>Ressourcen</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="88"/>
        <source>Questionaire</source>
        <translation>Fragebogen</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="145"/>
        <source>Join US</source>
        <translation>Mitmachen</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="150"/>
        <source>Internal Testing</source>
        <translation>Interne Tests</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="163"/>
        <source>Community News</source>
        <translation>Gemeinschaftsnachrichten</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="40"/>
        <source>Messages</source>
        <translation>Nachrichten</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="43"/>
        <source>Questionaires</source>
        <translation>Fragebogen</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="25"/>
        <source>About</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="29"/>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="39"/>
        <source>Version: %1</source>
        <translation>Version: %1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="40"/>
        <source>Deepin Messages</source>
        <translation>Deepin-Nachrichten</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="76"/>
        <source>Unlogged</source>
        <translation>Nicht angemeldet</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="111"/>
        <source>Sign in</source>
        <translation>Anmelden</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="123"/>
        <source>Sign out</source>
        <translation>Abmelden</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="51"/>
        <source>No messages yet.</source>
        <translation>Noch keine Nachrichten.</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="148"/>
        <source>%1 messages</source>
        <translation>%1 Nachrichten</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="152"/>
        <source>Mark all as read</source>
        <translation>Alle als gelesen markieren</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <location filename="../src/maincomponentplugin/list/NotifyDetail.qml" line="65"/>
        <source>View more</source>
        <translation>Mehr anzeigen</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="43"/>
        <source>No questionaires yet.</source>
        <translation>Noch keine Fragebögen.</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="88"/>
        <source>Expired on: %1</source>
        <translation>Abgelaufen am: %1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="116"/>
        <source>Fill In</source>
        <translation>Ausfüllen</translation>
    </message>
</context>
</TS>

==> deepin-home_1.0.7.orig.tar.xz: deepin-home-1.0.7/translations/deepin-home/de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>Card1</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Card1.qml" line="88"/>
        <source>Coming</source>
        <translation>Kommend</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="50"/>
        <source>Communication</source>
        <translation>Kommunikation</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="51"/>
        <source>Discuss and share here</source>
        <translation>Diskutieren und teilen Sie hier</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="60"/>
        <source>Bug Report</source>
        <translation>Problembericht</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="61"/>
        <source>Report issues you found</source>
        <translation>Melden Sie gefundene Probleme</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="68"/>
        <source>Suggestions</source>
        <translation>Vorschläge</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="69"/>
        <source>Submit your suggestions</source>
        <translation>Reichen Sie Ihre Vorschläge ein</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="83"/>
        <source>Resources</source>
        <translation>Ressourcen</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="88"/>
        <source>Questionaire</source>
        <translation>Fragebogen</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="145"/>
        <source>Join US</source>
        <translation>Mitmachen</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="150"/>
        <source>Internal Testing</source>
        <translation>Interne Tests</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="163"/>
        <source>Community News</source>
        <translation>Gemeinschaftsnachrichten</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="278"/>
        <source>Network error, please try later</source>
        <translation>Netzwerkfehler, bitte versuchen Sie es später</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="40"/>
        <source>Messages</source>
        <translation>Nachrichten</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="43"/>
        <source>Questionaires</source>
        <translation>Fragebogen</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="26"/>
        <source>Launch at system startup</source>
        <translation>Beim Systemstart starten</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="32"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="36"/>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="46"/>
        <source>Version: %1</source>
        <translation>Version: %1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="47"/>
        <source>Deepin Messages</source>
        <translation>Deepin-Nachrichten</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="83"/>
        <source>Unlogged</source>
        <translation>Nicht angemeldet</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="118"/>
        <source>Sign in</source>
        <translation>Anmelden</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="130"/>
        <source>Sign out</source>
        <translation>Abmelden</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="51"/>
        <source>No messages yet.</source>
        <translation>Noch keine Nachrichten.</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="148"/>
        <source>%1 messages</source>
        <translation>%1 Nachrichten</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="152"/>
        <source>Mark all as read</source>
        <translation>Alle als gelesen markieren</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <location filename="../src/maincomponentplugin/list/NotifyDetail.qml" line="65"/>
        <source>View more</source>
        <translation>Mehr anzeigen</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="43"/>
        <source>No questionaires yet.</source>
        <translation>Noch keine Fragebögen.</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="88"/>
        <source>Expired on: %1</source>
        <translation>Abgelaufen am: %1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="116"/>
        <source>Fill In</source>
        <translation>Ausfüllen</translation>
    </message>
</context>
</TS>
